ams.core.service.ROperationService
==================================

.. currentmodule:: ams.core.service

.. autoclass:: ROperationService

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: _generated/

   
       
       
          ~ROperationService.assign_memory
       
       
          ~ROperationService.evaluate
       
       
          ~ROperationService.get_names
       
       
          ~ROperationService.parse
       
       
          ~ROperationService.update
       
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: _generated/

   
      ~ROperationService.class_name
      ~ROperationService.n
      ~ROperationService.shape
      ~ROperationService.size
      ~ROperationService.v
   
   